==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/sk.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Správa parametrov Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "správa Galéria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Výška");
define('MANAGE_GALLERY_THUMB_WIDTH', "Náhľad Šírka obrázku");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Náhľady Výška Image");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Zachovať Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "ukázať tituly");
define('MANAGE_GALLERY_DISABLE_SORT', "zakázať Triediť");
define('MANAGE_GALLERY_DELETE_IMAGE', "zmazať obrázok");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Uloženie Triediť Objednávka");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliknite na &#39;Aktualizovať&#39; publikovať <br /> nahrané obrázky.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Všetky obrazy boli zmenšené a boli uložené nastavenia.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Došlo k chybe pri zmene veľkosti obrázkov alebo uloženie nastavení.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Disk (y) bol nahraný.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Došlo k chybe pri nahrávaní na disk (y).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Súbor, ktorý sa pokúšate nahrať, nie je obrázok.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Súbor, ktorý sa pokúšate nahrať, je príliš veľký.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titul bol uložený.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ste si istí, že chcete zmazať snímku");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Obraz bol zmazaný.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Došlo k chybe pri mazaní obraz.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Uloženie parametrov a zmenu veľkosti obrázkov, čakajte prosím ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Nahrávanie, čakajte prosím ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Poradie zoradenia nebol uložený. Chcete ušetriť poradie zoradenia?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Obraz triedenie objednávka bola uložená.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Nastala chyba pri ukladaní obrázku triedenia.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/sk.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Správa parametrov Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "správa Galéria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Výška");
define('MANAGE_GALLERY_THUMB_WIDTH', "Náhľad Šírka obrázku");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Náhľady Výška Image");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Zachovať Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "ukázať tituly");
define('MANAGE_GALLERY_DISABLE_SORT', "zakázať Triediť");
define('MANAGE_GALLERY_DELETE_IMAGE', "zmazať obrázok");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Uloženie Triediť Objednávka");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliknite na &#39;Aktualizovať&#39; publikovať <br /> nahrané obrázky.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Všetky obrazy boli zmenšené a boli uložené nastavenia.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Došlo k chybe pri zmene veľkosti obrázkov alebo uloženie nastavení.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Disk (y) bol nahraný.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Došlo k chybe pri nahrávaní na disk (y).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Súbor, ktorý sa pokúšate nahrať, nie je obrázok.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Súbor, ktorý sa pokúšate nahrať, je príliš veľký.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titul bol uložený.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ste si istí, že chcete zmazať snímku");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Obraz bol zmazaný.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Došlo k chybe pri mazaní obraz.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Uloženie parametrov a zmenu veľkosti obrázkov, čakajte prosím ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Nahrávanie, čakajte prosím ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Poradie zoradenia nebol uložený. Chcete ušetriť poradie zoradenia?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Obraz triedenie objednávka bola uložená.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Nastala chyba pri ukladaní obrázku triedenia.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Súbor, ktorý sa snažíte nahrať, je väčší ako nastavenie PHP „upload_max_filesize“ alebo „post_max_size“ PHP. Ak chcete zvýšiť tieto limity, kontaktujte svojho správcu systému.");
?>
